==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/SessionRestoreErrorSessionHasFinished.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::SessionRestoreErrorSessionHasFinished::BEGIN{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::SessionRestoreErrorSessionHasFinished::BEGIN{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;require overload;do
{"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::SessionRestoreErrorSessionHasFinished::notify{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;(my $self=shift (@_
));NXMsg::register_error ((""),
"\x65\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x73\x74\x6f\x72\x65\x45\x72\x72\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e\x48\x61\x73\x46\x69\x6e\x69\x73\x68\x65\x64"
,(0x1e1b+ 794-0x1ee1));NXMsg::error (
"\x65\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x73\x74\x6f\x72\x65\x45\x72\x72\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e\x48\x61\x73\x46\x69\x6e\x69\x73\x68\x65\x64"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/SessionRestoreErrorSessionHasFinished.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::SessionRestoreErrorSessionHasFinished::BEGIN{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::SessionRestoreErrorSessionHasFinished::BEGIN{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;require overload;do
{"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::SessionRestoreErrorSessionHasFinished::notify{package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;(my $self=shift (@_
));NXMsg::register_error ((""),
"\x65\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x73\x74\x6f\x72\x65\x45\x72\x72\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e\x48\x61\x73\x46\x69\x6e\x69\x73\x68\x65\x64"
,(0x16e0+ 408-0x1624));NXMsg::error (
"\x65\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x73\x74\x6f\x72\x65\x45\x72\x72\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e\x48\x61\x73\x46\x69\x6e\x69\x73\x68\x65\x64"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::SessionRestoreErrorSessionHasFinished;no warnings;"\x3f\x3f\x3f";
